==> apache-juneau-8.1.5-src.zip: juneau-8.1.5/juneau-core/juneau-marshall-rdf/src/main/java/org/apache/juneau/jena/annotation/RdfNs.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.jena.annotation;

import static java.lang.annotation.RetentionPolicy.*;

import java.lang.annotation.*;

/**
 * Namespace name/URL mapping pair.
 *
 * <p>
 * Used to identify a namespace/URI pair on a {@link RdfSchema#rdfNs() @RdfSchema(rdfNs)} annotation.
 */
@Documented
@Target({})
@Retention(RUNTIME)
@Inherited
public @interface RdfNs {

	/**
	 * RDF namespace URL.
	 */
	String namespaceURI();

	/**
	 * RDF namespace prefix.
	 */
	String prefix();
}

==> apache-juneau-9.1.0-src.zip: juneau-9.1.0/juneau-core/juneau-marshall-rdf/src/main/java/org/apache/juneau/jena/annotation/RdfNs.java <==
// ***************************************************************************************************************************
// * Licensed to the Apache Software Foundation (ASF) under one or more contributor license agreements.  See the NOTICE file *
// * distributed with this work for additional information regarding copyright ownership.  The ASF licenses this file        *
// * to you under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance            *
// * with the License.  You may obtain a copy of the License at                                                              *
// *                                                                                                                         *
// *  http://www.apache.org/licenses/LICENSE-2.0                                                                             *
// *                                                                                                                         *
// * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an  *
// * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the        *
// * specific language governing permissions and limitations under the License.                                              *
// ***************************************************************************************************************************
package org.apache.juneau.jena.annotation;

import static java.lang.annotation.RetentionPolicy.*;

import java.lang.annotation.*;

/**
 * Namespace name/URL mapping pair.
 *
 * <p>
 * Used to identify a namespace/URI pair on a {@link RdfSchema#rdfNs() @RdfSchema(rdfNs)} annotation.
 *
 * <h5 class='section'>See Also:</h5><ul>
 * 	<li class='link'>{doc jmr.RdfDetails}

 * </ul>
 */
@Documented
@Target({})
@Retention(RUNTIME)
@Inherited
public @interface RdfNs {

	/**
	 * RDF namespace URL.
	 *
	 * @return The annotation value.
	 */
	String namespaceURI();

	/**
	 * RDF namespace prefix.
	 *
	 * @return The annotation value.
	 */
	String prefix();
}
